@@ -21,6 +21,7 @@ SchoolTool flourish skin interfaces.
 """
 
 import zope.schema
+import zope.schema.interfaces
 import zope.viewlet.interfaces
 import zope.contentprovider.interfaces
 from zope.interface import Interface, Attribute
@@ -31,8 +32,6 @@ from zope.publisher.interfaces.browser import IBrowserPage
 from zope.traversing.interfaces import ITraversable
 from z3c.form.interfaces import IFormLayer
 
-from schooltool.common import SchoolToolMessage as _
-
 
 class IFlourishLayer(IDefaultBrowserLayer, IFormLayer):
     """SchoolTool flourish skin."""
@@ -153,3 +152,5 @@ class IAJAXPart(IViewlet, IFromPublication):
                      'was not obtained via publication).',
         default=True,
         required=False)
+
+
